from .get_wallet_active_chains import get_wallet_active_chains
from .get_wallet_net_worth import get_wallet_net_worth
from .get_wallet_stats import get_wallet_stats
from .get_wallet_token_balances_price import get_wallet_token_balances_price



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class MarketDataERC20Token(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "price_usd",
                    "price_24h_percent_change",
                    "token_logo",
                    "token_name",
                    "rank",
                    "token_decimals",
                    "token_symbol",
                    "contract_address",
                    "price_7d_percent_change",
                    "market_cap_usd",
                }
                
                class properties:
                    rank = schemas.IntSchema
                    token_name = schemas.StrSchema
                    token_symbol = schemas.StrSchema
                    token_logo = schemas.StrSchema
                    token_decimals = schemas.StrSchema
                    contract_address = schemas.StrSchema
                    price_usd = schemas.StrSchema
                    price_24h_percent_change = schemas.StrSchema
                    price_7d_percent_change = schemas.StrSchema
                    market_cap_usd = schemas.StrSchema
                    __annotations__ = {
                        "rank": rank,
                        "token_name": token_name,
                        "token_symbol": token_symbol,
                        "token_logo": token_logo,
                        "token_decimals": token_decimals,
                        "contract_address": contract_address,
                        "price_usd": price_usd,
                        "price_24h_percent_change": price_24h_percent_change,
                        "price_7d_percent_change": price_7d_percent_change,
                        "market_cap_usd": market_cap_usd,
                    }
        
            
            price_usd: MetaOapg.properties.price_usd
            price_24h_percent_change: MetaOapg.properties.price_24h_percent_change
            token_logo: MetaOapg.properties.token_logo
            token_name: MetaOapg.properties.token_name
            rank: MetaOapg.properties.rank
            token_decimals: MetaOapg.properties.token_decimals
            token_symbol: MetaOapg.properties.token_symbol
            contract_address: MetaOapg.properties.contract_address
            price_7d_percent_change: MetaOapg.properties.price_7d_percent_change
            market_cap_usd: MetaOapg.properties.market_cap_usd
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["rank"]) -> MetaOapg.properties.rank: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["token_decimals"]) -> MetaOapg.properties.token_decimals: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_24h_percent_change"]) -> MetaOapg.properties.price_24h_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_7d_percent_change"]) -> MetaOapg.properties.price_7d_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap_usd"]) -> MetaOapg.properties.market_cap_usd: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["rank", "token_name", "token_symbol", "token_logo", "token_decimals", "contract_address", "price_usd", "price_24h_percent_change", "price_7d_percent_change", "market_cap_usd", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["rank"]) -> MetaOapg.properties.rank: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["token_decimals"]) -> MetaOapg.properties.token_decimals: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_24h_percent_change"]) -> MetaOapg.properties.price_24h_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_7d_percent_change"]) -> MetaOapg.properties.price_7d_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap_usd"]) -> MetaOapg.properties.market_cap_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["rank", "token_name", "token_symbol", "token_logo", "token_decimals", "contract_address", "price_usd", "price_24h_percent_change", "price_7d_percent_change", "market_cap_usd", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                price_usd: typing.Union[MetaOapg.properties.price_usd, str, ],
                price_24h_percent_change: typing.Union[MetaOapg.properties.price_24h_percent_change, str, ],
                token_logo: typing.Union[MetaOapg.properties.token_logo, str, ],
                token_name: typing.Union[MetaOapg.properties.token_name, str, ],
                rank: typing.Union[MetaOapg.properties.rank, decimal.Decimal, int, ],
                token_decimals: typing.Union[MetaOapg.properties.token_decimals, str, ],
                token_symbol: typing.Union[MetaOapg.properties.token_symbol, str, ],
                contract_address: typing.Union[MetaOapg.properties.contract_address, str, ],
                price_7d_percent_change: typing.Union[MetaOapg.properties.price_7d_percent_change, str, ],
                market_cap_usd: typing.Union[MetaOapg.properties.market_cap_usd, str, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    price_usd=price_usd,
                    price_24h_percent_change=price_24h_percent_change,
                    token_logo=token_logo,
                    token_name=token_name,
                    rank=rank,
                    token_decimals=token_decimals,
                    token_symbol=token_symbol,
                    contract_address=contract_address,
                    price_7d_percent_change=price_7d_percent_change,
                    market_cap_usd=market_cap_usd,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MarketDataERC20Token':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class TokenTimestamp(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "block_timestamp",
            "block_number",
            "transaction_hash",
            "direction",
        }
        
        class properties:
            block_number = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            transaction_hash = schemas.StrSchema
            
            
            class direction(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "send": "SEND",
                        "receive": "RECEIVE",
                    }
                
                @schemas.classproperty
                def SEND(cls):
                    return cls("send")
                
                @schemas.classproperty
                def RECEIVE(cls):
                    return cls("receive")
            __annotations__ = {
                "block_number": block_number,
                "block_timestamp": block_timestamp,
                "transaction_hash": transaction_hash,
                "direction": direction,
            }

    
    block_timestamp: MetaOapg.properties.block_timestamp
    block_number: MetaOapg.properties.block_number
    transaction_hash: MetaOapg.properties.transaction_hash
    direction: MetaOapg.properties.direction
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["direction"]) -> MetaOapg.properties.direction: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["block_number", "block_timestamp", "transaction_hash", "direction", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["direction"]) -> MetaOapg.properties.direction: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["block_number", "block_timestamp", "transaction_hash", "direction", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        direction: typing.Union[MetaOapg.properties.direction, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TokenTimestamp':
        return super().__new__(
            cls,
            *args,
            block_timestamp=block_timestamp,
            block_number=block_number,
            transaction_hash=transaction_hash,
            direction=direction,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20TokenBalanceWithPrice(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "symbol",
            "balance_formatted",
            "usd_price",
            "usd_price_24hr_percent_change",
            "usd_price_24hr_usd_change",
            "use_value_24hr_usd_change",
            "portfolio_percentage",
            "balance",
            "possible_spam",
            "decimals",
            "name",
            "native_token",
            "usd_value",
        }
        
        class properties:
            name = schemas.StrSchema
            symbol = schemas.StrSchema
            decimals = schemas.IntSchema
            balance = schemas.StrSchema
            possible_spam = schemas.BoolSchema
            usd_price = schemas.StrSchema
            usd_price_24hr_percent_change = schemas.StrSchema
            usd_price_24hr_usd_change = schemas.StrSchema
            usd_value = schemas.NumberSchema
            portfolio_percentage = schemas.NumberSchema
            balance_formatted = schemas.StrSchema
            native_token = schemas.BoolSchema
            token_address = schemas.StrSchema
            logo = schemas.StrSchema
            thumbnail = schemas.StrSchema
            verified_contract = schemas.BoolSchema
            usd_value_24hr_usd_change = schemas.StrSchema
            __annotations__ = {
                "name": name,
                "symbol": symbol,
                "decimals": decimals,
                "balance": balance,
                "possible_spam": possible_spam,
                "usd_price": usd_price,
                "usd_price_24hr_percent_change": usd_price_24hr_percent_change,
                "usd_price_24hr_usd_change": usd_price_24hr_usd_change,
                "usd_value": usd_value,
                "portfolio_percentage": portfolio_percentage,
                "balance_formatted": balance_formatted,
                "native_token": native_token,
                "token_address": token_address,
                "logo": logo,
                "thumbnail": thumbnail,
                "verified_contract": verified_contract,
                "usd_value_24hr_usd_change": usd_value_24hr_usd_change,
            }
    
    symbol: MetaOapg.properties.symbol
    balance_formatted: MetaOapg.properties.balance_formatted
    usd_price: MetaOapg.properties.usd_price
    usd_price_24hr_percent_change: MetaOapg.properties.usd_price_24hr_percent_change
    usd_price_24hr_usd_change: MetaOapg.properties.usd_price_24hr_usd_change
    use_value_24hr_usd_change: schemas.AnyTypeSchema
    portfolio_percentage: MetaOapg.properties.portfolio_percentage
    balance: MetaOapg.properties.balance
    possible_spam: MetaOapg.properties.possible_spam
    decimals: MetaOapg.properties.decimals
    name: MetaOapg.properties.name
    native_token: MetaOapg.properties.native_token
    usd_value: MetaOapg.properties.usd_value
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usd_price"]) -> MetaOapg.properties.usd_price: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usd_price_24hr_percent_change"]) -> MetaOapg.properties.usd_price_24hr_percent_change: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usd_price_24hr_usd_change"]) -> MetaOapg.properties.usd_price_24hr_usd_change: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usd_value"]) -> MetaOapg.properties.usd_value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["portfolio_percentage"]) -> MetaOapg.properties.portfolio_percentage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["balance_formatted"]) -> MetaOapg.properties.balance_formatted: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["native_token"]) -> MetaOapg.properties.native_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["thumbnail"]) -> MetaOapg.properties.thumbnail: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verified_contract"]) -> MetaOapg.properties.verified_contract: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usd_value_24hr_usd_change"]) -> MetaOapg.properties.usd_value_24hr_usd_change: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "symbol", "decimals", "balance", "possible_spam", "usd_price", "usd_price_24hr_percent_change", "usd_price_24hr_usd_change", "usd_value", "portfolio_percentage", "balance_formatted", "native_token", "token_address", "logo", "thumbnail", "verified_contract", "usd_value_24hr_usd_change", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["possible_spam"]) -> MetaOapg.properties.possible_spam: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usd_price"]) -> MetaOapg.properties.usd_price: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24hr_percent_change"]) -> MetaOapg.properties.usd_price_24hr_percent_change: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24hr_usd_change"]) -> MetaOapg.properties.usd_price_24hr_usd_change: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usd_value"]) -> MetaOapg.properties.usd_value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["portfolio_percentage"]) -> MetaOapg.properties.portfolio_percentage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["balance_formatted"]) -> MetaOapg.properties.balance_formatted: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["native_token"]) -> MetaOapg.properties.native_token: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> typing.Union[MetaOapg.properties.token_address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["thumbnail"]) -> typing.Union[MetaOapg.properties.thumbnail, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verified_contract"]) -> typing.Union[MetaOapg.properties.verified_contract, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usd_value_24hr_usd_change"]) -> typing.Union[MetaOapg.properties.usd_value_24hr_usd_change, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "symbol", "decimals", "balance", "possible_spam", "usd_price", "usd_price_24hr_percent_change", "usd_price_24hr_usd_change", "usd_value", "portfolio_percentage", "balance_formatted", "native_token", "token_address", "logo", "thumbnail", "verified_contract", "usd_value_24hr_usd_change", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        balance_formatted: typing.Union[MetaOapg.properties.balance_formatted, str, ],
        usd_price: typing.Union[MetaOapg.properties.usd_price, str, ],
        usd_price_24hr_percent_change: typing.Union[MetaOapg.properties.usd_price_24hr_percent_change, str, ],
        usd_price_24hr_usd_change: typing.Union[MetaOapg.properties.usd_price_24hr_usd_change, str, ],
        use_value_24hr_usd_change: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        portfolio_percentage: typing.Union[MetaOapg.properties.portfolio_percentage, decimal.Decimal, int, float, ],
        balance: typing.Union[MetaOapg.properties.balance, str, ],
        possible_spam: typing.Union[MetaOapg.properties.possible_spam, bool, ],
        decimals: typing.Union[MetaOapg.properties.decimals, decimal.Decimal, int, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        native_token: typing.Union[MetaOapg.properties.native_token, bool, ],
        usd_value: typing.Union[MetaOapg.properties.usd_value, decimal.Decimal, int, float, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, schemas.Unset] = schemas.unset,
        logo: typing.Union[MetaOapg.properties.logo, str, schemas.Unset] = schemas.unset,
        thumbnail: typing.Union[MetaOapg.properties.thumbnail, str, schemas.Unset] = schemas.unset,
        verified_contract: typing.Union[MetaOapg.properties.verified_contract, bool, schemas.Unset] = schemas.unset,
        usd_value_24hr_usd_change: typing.Union[MetaOapg.properties.usd_value_24hr_usd_change, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20TokenBalanceWithPrice':
        return super().__new__(
            cls,
            *args,
            symbol=symbol,
            balance_formatted=balance_formatted,
            usd_price=usd_price,
            usd_price_24hr_percent_change=usd_price_24hr_percent_change,
            usd_price_24hr_usd_change=usd_price_24hr_usd_change,
            use_value_24hr_usd_change=use_value_24hr_usd_change,
            portfolio_percentage=portfolio_percentage,
            balance=balance,
            possible_spam=possible_spam,
            decimals=decimals,
            name=name,
            native_token=native_token,
            usd_value=usd_value,
            token_address=token_address,
            logo=logo,
            thumbnail=thumbnail,
            verified_contract=verified_contract,
            usd_value_24hr_usd_change=usd_value_24hr_usd_change,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class OhlcResult(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "pair_label",
            "candles",
            "exchange",
            "interval",
            "quote_currency",
            "pair_address",
        }
        
        class properties:
            pair_address = schemas.StrSchema
            pair_label = schemas.StrSchema
            exchange = schemas.StrSchema
            quote_currency = schemas.StrSchema
            interval = schemas.StrSchema
        
            @staticmethod
            def candles() -> typing.Type['OhlcCandles']:
                return OhlcCandles
            __annotations__ = {
                "pair_address": pair_address,
                "pair_label": pair_label,
                "exchange": exchange,
                "quote_currency": quote_currency,
                "interval": interval,
                "candles": candles,
            }
    
    pair_label: MetaOapg.properties.pair_label
    candles: 'OhlcCandles'
    exchange: MetaOapg.properties.exchange
    interval: MetaOapg.properties.interval
    quote_currency: MetaOapg.properties.quote_currency
    pair_address: MetaOapg.properties.pair_address
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pair_address"]) -> MetaOapg.properties.pair_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pair_label"]) -> MetaOapg.properties.pair_label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchange"]) -> MetaOapg.properties.exchange: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["quote_currency"]) -> MetaOapg.properties.quote_currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["interval"]) -> MetaOapg.properties.interval: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["candles"]) -> 'OhlcCandles': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["pair_address", "pair_label", "exchange", "quote_currency", "interval", "candles", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pair_address"]) -> MetaOapg.properties.pair_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pair_label"]) -> MetaOapg.properties.pair_label: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchange"]) -> MetaOapg.properties.exchange: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["quote_currency"]) -> MetaOapg.properties.quote_currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["interval"]) -> MetaOapg.properties.interval: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["candles"]) -> 'OhlcCandles': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["pair_address", "pair_label", "exchange", "quote_currency", "interval", "candles", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        pair_label: typing.Union[MetaOapg.properties.pair_label, str, ],
        candles: 'OhlcCandles',
        exchange: typing.Union[MetaOapg.properties.exchange, str, ],
        interval: typing.Union[MetaOapg.properties.interval, str, ],
        quote_currency: typing.Union[MetaOapg.properties.quote_currency, str, ],
        pair_address: typing.Union[MetaOapg.properties.pair_address, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OhlcResult':
        return super().__new__(
            cls,
            *args,
            pair_label=pair_label,
            candles=candles,
            exchange=exchange,
            interval=interval,
            quote_currency=quote_currency,
            pair_address=pair_address,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.ohlc_candles import OhlcCandles



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class OhlcCandles(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "volume",
                    "high",
                    "low",
                    "trades",
                    "close",
                    "open",
                    "timestamp",
                }
                
                class properties:
                    timestamp = schemas.StrSchema
                    open = schemas.NumberSchema
                    high = schemas.NumberSchema
                    low = schemas.NumberSchema
                    close = schemas.NumberSchema
                    volume = schemas.NumberSchema
                    trades = schemas.NumberSchema
                    __annotations__ = {
                        "timestamp": timestamp,
                        "open": open,
                        "high": high,
                        "low": low,
                        "close": close,
                        "volume": volume,
                        "trades": trades,
                    }
        
            
            volume: MetaOapg.properties.volume
            high: MetaOapg.properties.high
            low: MetaOapg.properties.low
            trades: MetaOapg.properties.trades
            close: MetaOapg.properties.close
            open: MetaOapg.properties.open
            timestamp: MetaOapg.properties.timestamp
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["open"]) -> MetaOapg.properties.open: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["high"]) -> MetaOapg.properties.high: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["low"]) -> MetaOapg.properties.low: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["close"]) -> MetaOapg.properties.close: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["volume"]) -> MetaOapg.properties.volume: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["trades"]) -> MetaOapg.properties.trades: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["timestamp", "open", "high", "low", "close", "volume", "trades", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["open"]) -> MetaOapg.properties.open: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["high"]) -> MetaOapg.properties.high: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["low"]) -> MetaOapg.properties.low: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["close"]) -> MetaOapg.properties.close: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["volume"]) -> MetaOapg.properties.volume: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["trades"]) -> MetaOapg.properties.trades: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["timestamp", "open", "high", "low", "close", "volume", "trades", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                volume: typing.Union[MetaOapg.properties.volume, decimal.Decimal, int, float, ],
                high: typing.Union[MetaOapg.properties.high, decimal.Decimal, int, float, ],
                low: typing.Union[MetaOapg.properties.low, decimal.Decimal, int, float, ],
                trades: typing.Union[MetaOapg.properties.trades, decimal.Decimal, int, float, ],
                close: typing.Union[MetaOapg.properties.close, decimal.Decimal, int, float, ],
                open: typing.Union[MetaOapg.properties.open, decimal.Decimal, int, float, ],
                timestamp: typing.Union[MetaOapg.properties.timestamp, str, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    volume=volume,
                    high=high,
                    low=low,
                    trades=trades,
                    close=close,
                    open=open,
                    timestamp=timestamp,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'OhlcCandles':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)



# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_auth import schemas  # noqa: F401


class BindRemoveDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "address",
            "blockchainType",
            "profileId",
        }
        
        class properties:
            
            
            class blockchainType(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "evm": "EVM",
                        "solana": "SOLANA",
                        "aptos": "APTOS",
                    }
                
                @schemas.classproperty
                def EVM(cls):
                    return cls("evm")
                
                @schemas.classproperty
                def SOLANA(cls):
                    return cls("solana")
                
                @schemas.classproperty
                def APTOS(cls):
                    return cls("aptos")
            address = schemas.StrSchema
            profileId = schemas.StrSchema
            publicKey = schemas.StrSchema
            __annotations__ = {
                "blockchainType": blockchainType,
                "address": address,
                "profileId": profileId,
                "publicKey": publicKey,
            }
    
    address: MetaOapg.properties.address
    blockchainType: MetaOapg.properties.blockchainType
    profileId: MetaOapg.properties.profileId
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blockchainType"]) -> MetaOapg.properties.blockchainType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["profileId"]) -> MetaOapg.properties.profileId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["publicKey"]) -> MetaOapg.properties.publicKey: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["blockchainType", "address", "profileId", "publicKey", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blockchainType"]) -> MetaOapg.properties.blockchainType: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["profileId"]) -> MetaOapg.properties.profileId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["publicKey"]) -> typing.Union[MetaOapg.properties.publicKey, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["blockchainType", "address", "profileId", "publicKey", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        blockchainType: typing.Union[MetaOapg.properties.blockchainType, str, ],
        profileId: typing.Union[MetaOapg.properties.profileId, str, ],
        publicKey: typing.Union[MetaOapg.properties.publicKey, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BindRemoveDto':
        return super().__new__(
            cls,
            *args,
            address=address,
            blockchainType=blockchainType,
            profileId=profileId,
            publicKey=publicKey,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DiscoveryToken(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "price_usd",
            "chain_id",
            "rating",
            "block_number",
            "net_volume_change_usd",
            "market_cap",
            "volume_change_usd",
            "block_timestamp",
            "on_chain_strength_index",
            "security_score",
            "token_name",
            "links",
            "token_age_in_days",
            "total_number_of_rating",
            "experienced_net_buyers_change",
            "fully_diluted_valuation",
            "token_address",
            "total_liquidity_locked_in_percent",
            "twitter_followers",
            "token_logo",
            "total_supply_locked_in_percent",
            "holders_change",
            "price_percent_change_usd",
            "token_symbol",
            "liquidity_change_usd",
        }
        
        class properties:
            chain_id = schemas.StrSchema
            token_address = schemas.StrSchema
            
            
            class token_name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'token_name':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class token_symbol(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'token_symbol':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class token_logo(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'token_logo':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class block_number(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'block_number':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class block_timestamp(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'block_timestamp':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def links() -> typing.Type['DiscoveryTokenLinks']:
                return DiscoveryTokenLinks
            
            
            class rating(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'rating':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class total_number_of_rating(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'total_number_of_rating':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class total_liquidity_locked_in_percent(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'total_liquidity_locked_in_percent':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class total_supply_locked_in_percent(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'total_supply_locked_in_percent':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class price_usd(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'price_usd':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class token_age_in_days(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'token_age_in_days':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class on_chain_strength_index(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'on_chain_strength_index':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class security_score(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'security_score':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class market_cap(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'market_cap':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class fully_diluted_valuation(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fully_diluted_valuation':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class twitter_followers(
                schemas.NumberBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, decimal.Decimal, int, float, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'twitter_followers':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def holders_change() -> typing.Type['TimeFrames']:
                return TimeFrames
        
            @staticmethod
            def liquidity_change_usd() -> typing.Type['TimeFrames']:
                return TimeFrames
        
            @staticmethod
            def experienced_net_buyers_change() -> typing.Type['TimeFrames']:
                return TimeFrames
        
            @staticmethod
            def volume_change_usd() -> typing.Type['TimeFrames']:
                return TimeFrames
        
            @staticmethod
            def net_volume_change_usd() -> typing.Type['TimeFrames']:
                return TimeFrames
        
            @staticmethod
            def price_percent_change_usd() -> typing.Type['TimeFrames']:
                return TimeFrames
            __annotations__ = {
                "chain_id": chain_id,
                "token_address": token_address,
                "token_name": token_name,
                "token_symbol": token_symbol,
                "token_logo": token_logo,
                "block_number": block_number,
                "block_timestamp": block_timestamp,
                "links": links,
                "rating": rating,
                "total_number_of_rating": total_number_of_rating,
                "total_liquidity_locked_in_percent": total_liquidity_locked_in_percent,
                "total_supply_locked_in_percent": total_supply_locked_in_percent,
                "price_usd": price_usd,
                "token_age_in_days": token_age_in_days,
                "on_chain_strength_index": on_chain_strength_index,
                "security_score": security_score,
                "market_cap": market_cap,
                "fully_diluted_valuation": fully_diluted_valuation,
                "twitter_followers": twitter_followers,
                "holders_change": holders_change,
                "liquidity_change_usd": liquidity_change_usd,
                "experienced_net_buyers_change": experienced_net_buyers_change,
                "volume_change_usd": volume_change_usd,
                "net_volume_change_usd": net_volume_change_usd,
                "price_percent_change_usd": price_percent_change_usd,
            }
    
    price_usd: MetaOapg.properties.price_usd
    chain_id: MetaOapg.properties.chain_id
    rating: MetaOapg.properties.rating
    block_number: MetaOapg.properties.block_number
    net_volume_change_usd: 'TimeFrames'
    market_cap: MetaOapg.properties.market_cap
    volume_change_usd: 'TimeFrames'
    block_timestamp: MetaOapg.properties.block_timestamp
    on_chain_strength_index: MetaOapg.properties.on_chain_strength_index
    security_score: MetaOapg.properties.security_score
    token_name: MetaOapg.properties.token_name
    links: 'DiscoveryTokenLinks'
    token_age_in_days: MetaOapg.properties.token_age_in_days
    total_number_of_rating: MetaOapg.properties.total_number_of_rating
    experienced_net_buyers_change: 'TimeFrames'
    fully_diluted_valuation: MetaOapg.properties.fully_diluted_valuation
    token_address: MetaOapg.properties.token_address
    total_liquidity_locked_in_percent: MetaOapg.properties.total_liquidity_locked_in_percent
    twitter_followers: MetaOapg.properties.twitter_followers
    token_logo: MetaOapg.properties.token_logo
    total_supply_locked_in_percent: MetaOapg.properties.total_supply_locked_in_percent
    holders_change: 'TimeFrames'
    price_percent_change_usd: 'TimeFrames'
    token_symbol: MetaOapg.properties.token_symbol
    liquidity_change_usd: 'TimeFrames'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["links"]) -> 'DiscoveryTokenLinks': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["rating"]) -> MetaOapg.properties.rating: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total_number_of_rating"]) -> MetaOapg.properties.total_number_of_rating: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total_liquidity_locked_in_percent"]) -> MetaOapg.properties.total_liquidity_locked_in_percent: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total_supply_locked_in_percent"]) -> MetaOapg.properties.total_supply_locked_in_percent: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_age_in_days"]) -> MetaOapg.properties.token_age_in_days: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["on_chain_strength_index"]) -> MetaOapg.properties.on_chain_strength_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["security_score"]) -> MetaOapg.properties.security_score: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["market_cap"]) -> MetaOapg.properties.market_cap: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fully_diluted_valuation"]) -> MetaOapg.properties.fully_diluted_valuation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["twitter_followers"]) -> MetaOapg.properties.twitter_followers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["holders_change"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["liquidity_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["experienced_net_buyers_change"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["volume_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["net_volume_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["price_percent_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["chain_id", "token_address", "token_name", "token_symbol", "token_logo", "block_number", "block_timestamp", "links", "rating", "total_number_of_rating", "total_liquidity_locked_in_percent", "total_supply_locked_in_percent", "price_usd", "token_age_in_days", "on_chain_strength_index", "security_score", "market_cap", "fully_diluted_valuation", "twitter_followers", "holders_change", "liquidity_change_usd", "experienced_net_buyers_change", "volume_change_usd", "net_volume_change_usd", "price_percent_change_usd", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_name"]) -> MetaOapg.properties.token_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_symbol"]) -> MetaOapg.properties.token_symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_logo"]) -> MetaOapg.properties.token_logo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["links"]) -> 'DiscoveryTokenLinks': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["rating"]) -> MetaOapg.properties.rating: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total_number_of_rating"]) -> MetaOapg.properties.total_number_of_rating: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total_liquidity_locked_in_percent"]) -> MetaOapg.properties.total_liquidity_locked_in_percent: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total_supply_locked_in_percent"]) -> MetaOapg.properties.total_supply_locked_in_percent: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_age_in_days"]) -> MetaOapg.properties.token_age_in_days: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["on_chain_strength_index"]) -> MetaOapg.properties.on_chain_strength_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["security_score"]) -> MetaOapg.properties.security_score: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["market_cap"]) -> MetaOapg.properties.market_cap: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fully_diluted_valuation"]) -> MetaOapg.properties.fully_diluted_valuation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["twitter_followers"]) -> MetaOapg.properties.twitter_followers: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["holders_change"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["liquidity_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["experienced_net_buyers_change"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["volume_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["net_volume_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["price_percent_change_usd"]) -> 'TimeFrames': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["chain_id", "token_address", "token_name", "token_symbol", "token_logo", "block_number", "block_timestamp", "links", "rating", "total_number_of_rating", "total_liquidity_locked_in_percent", "total_supply_locked_in_percent", "price_usd", "token_age_in_days", "on_chain_strength_index", "security_score", "market_cap", "fully_diluted_valuation", "twitter_followers", "holders_change", "liquidity_change_usd", "experienced_net_buyers_change", "volume_change_usd", "net_volume_change_usd", "price_percent_change_usd", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        price_usd: typing.Union[MetaOapg.properties.price_usd, None, decimal.Decimal, int, float, ],
        chain_id: typing.Union[MetaOapg.properties.chain_id, str, ],
        rating: typing.Union[MetaOapg.properties.rating, None, decimal.Decimal, int, float, ],
        block_number: typing.Union[MetaOapg.properties.block_number, None, decimal.Decimal, int, float, ],
        net_volume_change_usd: 'TimeFrames',
        market_cap: typing.Union[MetaOapg.properties.market_cap, None, decimal.Decimal, int, float, ],
        volume_change_usd: 'TimeFrames',
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, None, str, ],
        on_chain_strength_index: typing.Union[MetaOapg.properties.on_chain_strength_index, None, decimal.Decimal, int, float, ],
        security_score: typing.Union[MetaOapg.properties.security_score, None, decimal.Decimal, int, float, ],
        token_name: typing.Union[MetaOapg.properties.token_name, None, str, ],
        links: 'DiscoveryTokenLinks',
        token_age_in_days: typing.Union[MetaOapg.properties.token_age_in_days, None, decimal.Decimal, int, float, ],
        total_number_of_rating: typing.Union[MetaOapg.properties.total_number_of_rating, None, decimal.Decimal, int, float, ],
        experienced_net_buyers_change: 'TimeFrames',
        fully_diluted_valuation: typing.Union[MetaOapg.properties.fully_diluted_valuation, None, decimal.Decimal, int, float, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, ],
        total_liquidity_locked_in_percent: typing.Union[MetaOapg.properties.total_liquidity_locked_in_percent, None, decimal.Decimal, int, float, ],
        twitter_followers: typing.Union[MetaOapg.properties.twitter_followers, None, decimal.Decimal, int, float, ],
        token_logo: typing.Union[MetaOapg.properties.token_logo, None, str, ],
        total_supply_locked_in_percent: typing.Union[MetaOapg.properties.total_supply_locked_in_percent, None, decimal.Decimal, int, float, ],
        holders_change: 'TimeFrames',
        price_percent_change_usd: 'TimeFrames',
        token_symbol: typing.Union[MetaOapg.properties.token_symbol, None, str, ],
        liquidity_change_usd: 'TimeFrames',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DiscoveryToken':
        return super().__new__(
            cls,
            *args,
            price_usd=price_usd,
            chain_id=chain_id,
            rating=rating,
            block_number=block_number,
            net_volume_change_usd=net_volume_change_usd,
            market_cap=market_cap,
            volume_change_usd=volume_change_usd,
            block_timestamp=block_timestamp,
            on_chain_strength_index=on_chain_strength_index,
            security_score=security_score,
            token_name=token_name,
            links=links,
            token_age_in_days=token_age_in_days,
            total_number_of_rating=total_number_of_rating,
            experienced_net_buyers_change=experienced_net_buyers_change,
            fully_diluted_valuation=fully_diluted_valuation,
            token_address=token_address,
            total_liquidity_locked_in_percent=total_liquidity_locked_in_percent,
            twitter_followers=twitter_followers,
            token_logo=token_logo,
            total_supply_locked_in_percent=total_supply_locked_in_percent,
            holders_change=holders_change,
            price_percent_change_usd=price_percent_change_usd,
            token_symbol=token_symbol,
            liquidity_change_usd=liquidity_change_usd,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.discovery_token_links import DiscoveryTokenLinks
from openapi_evm_api.model.time_frames import TimeFrames



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.block_block_number_or_hash.get import GetBlock
from openapi_evm_api.paths.block_block_number_or_hash_stats.get import GetBlockStats
from openapi_evm_api.paths.date_to_block.get import GetDateToBlock


class BlockApi(
    GetBlock,
    GetBlockStats,
    GetDateToBlock,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class MarketDataTopCryptoCurrenciesByMarketCap(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.AnyTypeSchema,
        ):
        
        
            class MetaOapg:
                required = {
                    "price_usd",
                    "circulating_supply",
                    "symbol",
                    "total_volume",
                    "total_supply",
                    "market_cap_rank",
                    "market_cap_usd",
                    "market_cap_24h_change",
                    "usd_price_24h_percent_change",
                    "usd_price_ath",
                    "ath_percent_change",
                    "usd_price_24h_low",
                    "market_cap_24h_percent_change",
                    "max_supply",
                    "name",
                    "usd_price_24h_high",
                    "logo",
                    "rank",
                    "usd_price_24h_change",
                    "ath_date",
                }
                
                class properties:
                    symbol = schemas.StrSchema
                    name = schemas.StrSchema
                    logo = schemas.StrSchema
                    circulating_supply = schemas.StrSchema
                    total_supply = schemas.StrSchema
                    max_supply = schemas.StrSchema
                    market_cap_usd = schemas.StrSchema
                    market_cap_rank = schemas.StrSchema
                    market_cap_24h_change = schemas.StrSchema
                    market_cap_24h_percent_change = schemas.StrSchema
                    total_volume = schemas.StrSchema
                    price_usd = schemas.StrSchema
                    usd_price_24h_high = schemas.StrSchema
                    usd_price_24h_low = schemas.StrSchema
                    usd_price_24h_change = schemas.StrSchema
                    usd_price_24h_percent_change = schemas.StrSchema
                    usd_price_ath = schemas.StrSchema
                    ath_percent_change = schemas.StrSchema
                    ath_date = schemas.StrSchema
                    __annotations__ = {
                        "symbol": symbol,
                        "name": name,
                        "logo": logo,
                        "circulating_supply": circulating_supply,
                        "total_supply": total_supply,
                        "max_supply": max_supply,
                        "market_cap_usd": market_cap_usd,
                        "market_cap_rank": market_cap_rank,
                        "market_cap_24h_change": market_cap_24h_change,
                        "market_cap_24h_percent_change": market_cap_24h_percent_change,
                        "total_volume": total_volume,
                        "price_usd": price_usd,
                        "usd_price_24h_high": usd_price_24h_high,
                        "usd_price_24h_low": usd_price_24h_low,
                        "usd_price_24h_change": usd_price_24h_change,
                        "usd_price_24h_percent_change": usd_price_24h_percent_change,
                        "usd_price_ath": usd_price_ath,
                        "ath_percent_change": ath_percent_change,
                        "ath_date": ath_date,
                    }
        
            
            price_usd: MetaOapg.properties.price_usd
            circulating_supply: MetaOapg.properties.circulating_supply
            symbol: MetaOapg.properties.symbol
            total_volume: MetaOapg.properties.total_volume
            total_supply: MetaOapg.properties.total_supply
            market_cap_rank: MetaOapg.properties.market_cap_rank
            market_cap_usd: MetaOapg.properties.market_cap_usd
            market_cap_24h_change: MetaOapg.properties.market_cap_24h_change
            usd_price_24h_percent_change: MetaOapg.properties.usd_price_24h_percent_change
            usd_price_ath: MetaOapg.properties.usd_price_ath
            ath_percent_change: MetaOapg.properties.ath_percent_change
            usd_price_24h_low: MetaOapg.properties.usd_price_24h_low
            market_cap_24h_percent_change: MetaOapg.properties.market_cap_24h_percent_change
            max_supply: MetaOapg.properties.max_supply
            name: MetaOapg.properties.name
            usd_price_24h_high: MetaOapg.properties.usd_price_24h_high
            logo: MetaOapg.properties.logo
            rank: schemas.AnyTypeSchema
            usd_price_24h_change: MetaOapg.properties.usd_price_24h_change
            ath_date: MetaOapg.properties.ath_date
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["circulating_supply"]) -> MetaOapg.properties.circulating_supply: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_supply"]) -> MetaOapg.properties.total_supply: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["max_supply"]) -> MetaOapg.properties.max_supply: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap_usd"]) -> MetaOapg.properties.market_cap_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap_rank"]) -> MetaOapg.properties.market_cap_rank: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap_24h_change"]) -> MetaOapg.properties.market_cap_24h_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["market_cap_24h_percent_change"]) -> MetaOapg.properties.market_cap_24h_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_volume"]) -> MetaOapg.properties.total_volume: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["usd_price_24h_high"]) -> MetaOapg.properties.usd_price_24h_high: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["usd_price_24h_low"]) -> MetaOapg.properties.usd_price_24h_low: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["usd_price_24h_change"]) -> MetaOapg.properties.usd_price_24h_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["usd_price_24h_percent_change"]) -> MetaOapg.properties.usd_price_24h_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["usd_price_ath"]) -> MetaOapg.properties.usd_price_ath: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ath_percent_change"]) -> MetaOapg.properties.ath_percent_change: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["ath_date"]) -> MetaOapg.properties.ath_date: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["symbol", "name", "logo", "circulating_supply", "total_supply", "max_supply", "market_cap_usd", "market_cap_rank", "market_cap_24h_change", "market_cap_24h_percent_change", "total_volume", "price_usd", "usd_price_24h_high", "usd_price_24h_low", "usd_price_24h_change", "usd_price_24h_percent_change", "usd_price_ath", "ath_percent_change", "ath_date", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["circulating_supply"]) -> MetaOapg.properties.circulating_supply: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_supply"]) -> MetaOapg.properties.total_supply: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["max_supply"]) -> MetaOapg.properties.max_supply: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap_usd"]) -> MetaOapg.properties.market_cap_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap_rank"]) -> MetaOapg.properties.market_cap_rank: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap_24h_change"]) -> MetaOapg.properties.market_cap_24h_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["market_cap_24h_percent_change"]) -> MetaOapg.properties.market_cap_24h_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_volume"]) -> MetaOapg.properties.total_volume: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["price_usd"]) -> MetaOapg.properties.price_usd: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24h_high"]) -> MetaOapg.properties.usd_price_24h_high: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24h_low"]) -> MetaOapg.properties.usd_price_24h_low: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24h_change"]) -> MetaOapg.properties.usd_price_24h_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["usd_price_24h_percent_change"]) -> MetaOapg.properties.usd_price_24h_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["usd_price_ath"]) -> MetaOapg.properties.usd_price_ath: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ath_percent_change"]) -> MetaOapg.properties.ath_percent_change: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["ath_date"]) -> MetaOapg.properties.ath_date: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["symbol", "name", "logo", "circulating_supply", "total_supply", "max_supply", "market_cap_usd", "market_cap_rank", "market_cap_24h_change", "market_cap_24h_percent_change", "total_volume", "price_usd", "usd_price_24h_high", "usd_price_24h_low", "usd_price_24h_change", "usd_price_24h_percent_change", "usd_price_ath", "ath_percent_change", "ath_date", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                price_usd: typing.Union[MetaOapg.properties.price_usd, str, ],
                circulating_supply: typing.Union[MetaOapg.properties.circulating_supply, str, ],
                symbol: typing.Union[MetaOapg.properties.symbol, str, ],
                total_volume: typing.Union[MetaOapg.properties.total_volume, str, ],
                total_supply: typing.Union[MetaOapg.properties.total_supply, str, ],
                market_cap_rank: typing.Union[MetaOapg.properties.market_cap_rank, str, ],
                market_cap_usd: typing.Union[MetaOapg.properties.market_cap_usd, str, ],
                market_cap_24h_change: typing.Union[MetaOapg.properties.market_cap_24h_change, str, ],
                usd_price_24h_percent_change: typing.Union[MetaOapg.properties.usd_price_24h_percent_change, str, ],
                usd_price_ath: typing.Union[MetaOapg.properties.usd_price_ath, str, ],
                ath_percent_change: typing.Union[MetaOapg.properties.ath_percent_change, str, ],
                usd_price_24h_low: typing.Union[MetaOapg.properties.usd_price_24h_low, str, ],
                market_cap_24h_percent_change: typing.Union[MetaOapg.properties.market_cap_24h_percent_change, str, ],
                max_supply: typing.Union[MetaOapg.properties.max_supply, str, ],
                name: typing.Union[MetaOapg.properties.name, str, ],
                usd_price_24h_high: typing.Union[MetaOapg.properties.usd_price_24h_high, str, ],
                logo: typing.Union[MetaOapg.properties.logo, str, ],
                rank: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                usd_price_24h_change: typing.Union[MetaOapg.properties.usd_price_24h_change, str, ],
                ath_date: typing.Union[MetaOapg.properties.ath_date, str, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    price_usd=price_usd,
                    circulating_supply=circulating_supply,
                    symbol=symbol,
                    total_volume=total_volume,
                    total_supply=total_supply,
                    market_cap_rank=market_cap_rank,
                    market_cap_usd=market_cap_usd,
                    market_cap_24h_change=market_cap_24h_change,
                    usd_price_24h_percent_change=usd_price_24h_percent_change,
                    usd_price_ath=usd_price_ath,
                    ath_percent_change=ath_percent_change,
                    usd_price_24h_low=usd_price_24h_low,
                    market_cap_24h_percent_change=market_cap_24h_percent_change,
                    max_supply=max_supply,
                    name=name,
                    usd_price_24h_high=usd_price_24h_high,
                    logo=logo,
                    rank=rank,
                    usd_price_24h_change=usd_price_24h_change,
                    ath_date=ath_date,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MarketDataTopCryptoCurrenciesByMarketCap':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)
